@@ -1,5 +1,5 @@
 """Top-level package for NFE Parser."""
 
 __author__ = """Goncalo Magno"""
-__email__ = 'goncalo@gmagno.dev'
-__version__ = '0.1.0'
+__email__ = "goncalo@gmagno.dev"
+__version__ = "0.4.0"
